@@ -16,6 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -1178,8 +1179,8 @@ static void draw_shrink_rule (DviContext *dvi, int x, int y, Uint w, Uint h, int
 	
 	hs = dvi->params.hshrink;
 	vs = dvi->params.vshrink;
-	fg = dvi->params.fg;
-	bg = dvi->params.bg;
+	fg = dvi->curr_fg;
+	bg = dvi->curr_bg;
 
 	if (MDVI_ENABLED(dvi, MDVI_PARAM_ANTIALIASED)) {
 		npixels = vs * hs + 1;
