@@ -63,8 +63,8 @@ static void impress_document_document_thumbnails_iface_init (EvDocumentThumbnail
 
 EV_BACKEND_REGISTER_WITH_CODE (ImpressDocument, impress_document,
 		         {
-			   G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
-						  impress_document_document_thumbnails_iface_init);
+			   EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
+							   impress_document_document_thumbnails_iface_init);
 			 });
 
 /* Renderer */
@@ -489,7 +489,6 @@ impress_document_thumbnails_get_thumbnail (EvDocumentThumbnails *document,
 {
   GdkPixbuf *pixbuf;
   GdkPixbuf *scaled_pixbuf;
-  gdouble w, h;
 
   pixbuf = impress_document_render_pixbuf (EV_DOCUMENT (document), rc);
   scaled_pixbuf = gdk_pixbuf_scale_simple (pixbuf,
