@@ -26,6 +26,10 @@
 #include "ev-page-cache.h"
 #include "ev-image.h"
 #include "ev-form-field.h"
+#include "ev-selection.h"
+#include "ev-transition-animation.h"
+
+#define DRAG_HISTORY 10
 
 /* Information for middle clicking and moving around the doc */
 typedef struct {
@@ -33,14 +37,27 @@ typedef struct {
 	GdkPoint start;
 	gdouble hadj;
 	gdouble vadj;
+	guint drag_timeout_id;
+	guint release_timeout_id;
+	GdkPoint buffer[DRAG_HISTORY];
+	GdkPoint momentum;
 } DragInfo;
 
+/* Autoscrolling */
+typedef struct {
+	gboolean autoscrolling;
+	guint last_y;
+	guint start_y;
+	guint timeout_id;	
+} AutoScrollInfo;
+
 /* Information for handling selection */
 typedef struct {
 	gboolean in_drag;
 	GdkPoint start;
 	gboolean in_selection;
 	GList *selections;
+	EvSelectionStyle style;
 } SelectionInfo;
 
 /* Information for handling images DND */
@@ -63,7 +80,8 @@ typedef enum {
 	EV_VIEW_CURSOR_LINK,
 	EV_VIEW_CURSOR_WAIT,
 	EV_VIEW_CURSOR_HIDDEN,
-	EV_VIEW_CURSOR_DRAG
+	EV_VIEW_CURSOR_DRAG,
+	EV_VIEW_CURSOR_AUTOSCROLL,
 } EvViewCursor;
 
 typedef enum {
@@ -131,6 +149,9 @@ struct _EvView {
 
 	/* Information for middle clicking and dragging around. */
 	DragInfo drag_info;
+	
+	/* Autoscrolling */
+	AutoScrollInfo scroll_info;
 
 	/* Selection */
 	GdkPoint motion;
@@ -152,6 +173,8 @@ struct _EvView {
 	/* Goto Popup */
 	GtkWidget *goto_window;
 	GtkWidget *goto_entry;
+
+	EvTransitionAnimation *animation;
 };
 
 struct _EvViewClass {
